@@ -4,7 +4,7 @@ use strict;
 
 use Mojo::Base 'Test::Mojo';
 use Mojo::Util 'squish';
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 sub trimmed_content_is {
     my $self = shift;
@@ -18,7 +18,7 @@ sub trimmed_content_is {
     $value =~ s{> <}{><}g;
     $got =~ s{> <}{><}g;
     $desc ||= 'exact match for trimmed content';
-    $desc .= (defined $error ? " (Error: $error)" : '');
+    $desc .= (defined $error && length $error ? " (Error: $error)" : '');
 
     return $self->_test('is', $got, $value, $desc);
 }
